==> qmapshack_1.16.1.orig.tar.gz: qmapshack-V_1.16.1/src/qmaptool/tool/CToolCutMap.h <==
/**********************************************************************************************
    Copyright (C) 2017 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CTOOLCUTMAP_H
#define CTOOLCUTMAP_H

#include "items/IItem.h"
#include "tool/ITool.h"
#include "tool/IToolGui.h"
#include "ui_IToolCutMap.h"

class CToolCutMap : public IToolGui, public ITool, private Ui::IToolCutMap
{
    Q_OBJECT
public:
    CToolCutMap(QWidget* parent);
    virtual ~CToolCutMap();

    void setupChanged() override;

    FORWARD_LIST_ALL(itemList)


private slots:
    void slotAddItem(const QString& filename, QListWidget* list);
    void slotMapSelectionChanged();
    void slotSomethingChanged();
    void slotStart();
    void slotFinished(qint32 id);

private:
    void buildCmd(QList<CShellCmd>& cmds, const IItem* iitem) override;
};

#endif //CTOOLCUTMAP_H

==> qmapshack_1.18.0.orig.tar.gz: qmapshack-V_1.18.0/src/qmaptool/tool/CToolCutMap.h <==
/**********************************************************************************************
    Copyright (C) 2017 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CTOOLCUTMAP_H
#define CTOOLCUTMAP_H

#include "items/IItem.h"
#include "tool/ITool.h"
#include "tool/IToolGui.h"
#include "ui_IToolCutMap.h"

class CToolCutMap : public IToolGui, public ITool, private Ui::IToolCutMap {
  Q_OBJECT
 public:
  CToolCutMap(QWidget* parent);
  virtual ~CToolCutMap();

  void setupChanged() override;

  FORWARD_LIST_ALL(itemList)

 private slots:
  void slotAddItem(const QString& filename, QListWidget* list);
  void slotMapSelectionChanged();
  void slotSomethingChanged();
  void slotStart();
  void slotFinished(qint32 id);

 private:
  void buildCmd(QList<CShellCmd>& cmds, const IItem* iitem) override;
};

#endif  // CTOOLCUTMAP_H
